@@ -5,7 +5,7 @@ use Dist::Zilla;
 use PerlX::Maybe qw( maybe );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.40'; # VERSION
+our $VERSION = '1.42'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -85,7 +85,7 @@ sub configure
 
   ));
 
-  unless($] < 5.010000)
+  if($] >= 5.010000 && $^O ne 'MSWin32')
   {
     $self->add_bundle('Git' => {
       allow_dirty => [ qw( dist.ini Changes README.md ) ],
@@ -114,7 +114,6 @@ sub configure
     
   $self->add_plugins(qw(
 
-    Author::Plicease::TransformTravis
     InstallGuide
     MinimumPerl
     ConfirmRelease
@@ -164,7 +163,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.40
+version 1.42
 
 =head1 SYNOPSIS
 
@@ -174,7 +173,7 @@ In your dist.ini:
 
 =head1 DESCRIPTION
 
-This Dist::Zilla plugin bundle is the equivalent to
+This Dist::Zilla plugin bundle is mostly equivalent to
 
  # Basic - UploadToCPAN, Readme, ExtraTests, and ConfirmRelease
  [GatherDir]
@@ -207,8 +206,6 @@ This Dist::Zilla plugin bundle is the equivalent to
  repository.github = user:plicease
  homepage = http://perl.wdlabs.com/%{dist}/
  
- [Author::Plicease::TransformTravis]
- 
  [InstallGuide]
  [MinimumPerl]
  [ConfirmRelease] 
@@ -226,6 +223,24 @@ This Dist::Zilla plugin bundle is the equivalent to
  [Author::Plicease::MarkDownCleanup]
  [Author::Plicease::Recommend]
 
+Some exceptions:
+
+=over 4
+
+=item Perl 5.8
+
+L<[@Git]|Dist::Zilla::PluginBundle::Git> does not support Perl 5.8, so it
+is not a prereq there, and it isn't included in the bundle.  As a result
+releasing from Perl 5.8 is not allowed.
+
+=item MSWin32
+
+Installing L<[@Git]|Dist::Zilla::PluginBundle::Git> on MSWin32 is a pain
+so it is also not a prereq on that platform, isn't used and as a result
+releasing from MSWin32 is not allowed.
+
+=back
+
 =head1 OPTIONS
 
 =head2 installer
